@@ -1,6 +1,16 @@
 import os
 import csv
 import xmlrpclib
+import urllib2
+
+from bibos_utils.bibos_config import BibOSConfig
+
+
+def get_default_admin(verbose=False):
+    conf_data = BibOSConfig().get_data()
+    admin_url = conf_data.get('admin_url', 'http://bibos.magenta-aps.dk')
+    xml_rpc_url = conf_data.get('xml_rpc_url', '/admin-xml/')
+    return BibOSAdmin(''.join([admin_url, xml_rpc_url]), verbose=verbose)
 
 
 # Thanks to A. Ellerton for this
@@ -20,11 +30,14 @@ class ProxyTransport(xmlrpclib.Transport):
     A. Ellerton 2006-07-06
     """
 
+    def __init__(self, schema='http'):
+        xmlrpclib.Transport.__init__(self)
+        self.schema = schema
+
     def request(self, host, handler, request_body, verbose):
-        import urllib2
 
         self.verbose = verbose
-        url = 'http://' + host + handler
+        url = self.schema + '://' + host + handler
 
         request = urllib2.Request(url)
         request.add_data(request_body)
@@ -49,7 +62,9 @@ class BibOSAdmin(object):
         rpc_args = {'verbose': verbose, 'allow_none': True}
         # Use proxy if present
         if 'http_proxy' in os.environ:
-            rpc_args['transport'] = ProxyTransport()
+            rpc_args['transport'] = ProxyTransport(
+                schema=url[:url.index(':')]
+            )
 
         self._rpc_srv = xmlrpclib.ServerProxy(self._url, **rpc_args)
 
@@ -68,12 +83,16 @@ class BibOSAdmin(object):
         return self._rpc_srv.send_status_info(pc_uid, package_data, job_data,
                                               update_required)
 
-    def get_instructions(self, pc_uid):
-        return self._rpc_srv.get_instructions(pc_uid)
+    def get_instructions(self, pc_uid, update_data):
+        return self._rpc_srv.get_instructions(pc_uid, update_data)
 
     def get_proxy_setup(self, pc_uid):
         return self._rpc_srv.get_proxy_setup(pc_uid)
 
+    def push_config_keys(self, pc_uid, config_dict):
+        return self._rpc_srv.push_config_keys(pc_uid, config_dict)
+
+
 if __name__ == '__main__':
     """Simple test suite."""
     import netifaces
