@@ -5,7 +5,35 @@
     # Attempt to get shared config file from gateway.
     # It this fails, the user must enter the corresponding data (site and 
     # admin_url) manually.
-    ADMIN_SITE="https://$(bibos_find_gateway 2> /dev/null)" 
+    if [ "$(id -u)" != "0" ]
+    then
+        echo "Dette program skal køres som root." 1>&2
+        exit 1
+    fi
+    
+    echo "Indtast gateway, tryk <ENTER> for ingen gateway eller automatisk opsætning"
+    read ADMIN_IP
+
+    if [[ -z $ADMIN_IP ]]
+    then
+        # No gateway entered by user
+        ADMIN_SITE="https://$(bibos_find_gateway 2> /dev/null)" 
+    else
+        # User entered IP address or hostname - test if reachable by ping
+        echo "Checker forbindelsen til gateway ..."
+        ping -c 1 $ADMIN_IP 2>1 > /dev/null
+        if [[ $? -ne 0 ]]
+        then
+            echo "Ugyldig gateway-adresse ($ADMIN_IP) - prøv igen."
+            exit -1
+        else
+            echo "OK"
+        fi
+        # Gateway is pingable - we assume that means it's OK.
+        ADMIN_SITE="https://$ADMIN_IP"
+        set_bibos_config gateway "$ADMIN_IP"
+    fi
+
     SHARED_CONFIG="/tmp/bibos.conf"
     curl -s "$ADMIN_SITE/bibos.conf" -o "$SHARED_CONFIG"
 
